@@ -1,5 +1,5 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+# For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt
 
 """Exceptions coverage.py can raise."""
 
@@ -11,7 +11,18 @@ from typing import Any
 class CoverageException(Exception):
     """The base class of all exceptions raised by Coverage.py."""
 
-    def __init__(self, *args: Any, slug: str | None = None) -> None:
+    def __init__(
+        self,
+        *args: Any,
+        slug: str | None = None,
+    ) -> None:
+        """Create an exception.
+
+        Args:
+            slug: A short string identifying the exception, will be used for
+                linking to documentation.
+        """
+
         super().__init__(*args)
         self.slug = slug
 
